summaryrefslogtreecommitdiffstats
path: root/mandoline/ui/omnibox/omnibox_application.cc
diff options
context:
space:
mode:
Diffstat (limited to 'mandoline/ui/omnibox/omnibox_application.cc')
-rw-r--r--mandoline/ui/omnibox/omnibox_application.cc18
1 files changed, 9 insertions, 9 deletions
diff --git a/mandoline/ui/omnibox/omnibox_application.cc b/mandoline/ui/omnibox/omnibox_application.cc
index c3b42de..18930e3 100644
--- a/mandoline/ui/omnibox/omnibox_application.cc
+++ b/mandoline/ui/omnibox/omnibox_application.cc
@@ -26,7 +26,7 @@ namespace mandoline {
////////////////////////////////////////////////////////////////////////////////
// OmniboxImpl
-class OmniboxImpl : public mus::ViewTreeDelegate,
+class OmniboxImpl : public mojo::ViewTreeDelegate,
public views::LayoutManager,
public views::TextfieldController,
public Omnibox {
@@ -37,9 +37,9 @@ class OmniboxImpl : public mus::ViewTreeDelegate,
~OmniboxImpl() override;
private:
- // Overridden from mus::ViewTreeDelegate:
- void OnEmbed(mus::View* root) override;
- void OnConnectionLost(mus::ViewTreeConnection* connection) override;
+ // Overridden from mojo::ViewTreeDelegate:
+ void OnEmbed(mojo::View* root) override;
+ void OnConnectionLost(mojo::ViewTreeConnection* connection) override;
// Overridden from views::LayoutManager:
gfx::Size GetPreferredSize(const views::View* view) const override;
@@ -59,7 +59,7 @@ class OmniboxImpl : public mus::ViewTreeDelegate,
scoped_ptr<AuraInit> aura_init_;
mojo::ApplicationImpl* app_;
- mus::View* root_;
+ mojo::View* root_;
mojo::String url_;
views::Textfield* edit_;
mojo::Binding<Omnibox> binding_;
@@ -110,9 +110,9 @@ OmniboxImpl::OmniboxImpl(mojo::ApplicationImpl* app,
OmniboxImpl::~OmniboxImpl() {}
////////////////////////////////////////////////////////////////////////////////
-// OmniboxImpl, mus::ViewTreeDelegate implementation:
+// OmniboxImpl, mojo::ViewTreeDelegate implementation:
-void OmniboxImpl::OnEmbed(mus::View* root) {
+void OmniboxImpl::OnEmbed(mojo::View* root) {
root_ = root;
if (!aura_init_.get()) {
@@ -148,7 +148,7 @@ void OmniboxImpl::OnEmbed(mus::View* root) {
ShowWindow();
}
-void OmniboxImpl::OnConnectionLost(mus::ViewTreeConnection* connection) {
+void OmniboxImpl::OnConnectionLost(mojo::ViewTreeConnection* connection) {
root_ = nullptr;
}
@@ -190,7 +190,7 @@ bool OmniboxImpl::HandleKeyEvent(views::Textfield* sender,
void OmniboxImpl::GetViewTreeClient(
mojo::InterfaceRequest<mojo::ViewTreeClient> request) {
- mus::ViewTreeConnection::Create(this, request.Pass());
+ mojo::ViewTreeConnection::Create(this, request.Pass());
}
void OmniboxImpl::ShowForURL(const mojo::String& url) {